@@ -113,6 +113,10 @@ class Model:
         return dec_var
 
     def ambiguity(self):
+        """
+        Returns an event-wise ambiguity set with the given number of scenarios
+        decalred in creating the DRO model.
+        """
 
         if self.all_constr:
             raise SyntaxError('Ambiguity set must be specified ' +
@@ -159,6 +163,10 @@ class Model:
 
         return wks_set
 
+    def adro(self, *args):
+
+        return self.wks(*args)
+
     def rule_var(self):
 
         if self.var_ev_list is not None:
@@ -245,6 +253,19 @@ class Model:
         return self.var_ev_list
 
     def min(self, obj):
+        """
+        Minimize the given objective function.
+
+        Parameters
+        ----------
+        obj
+            An objective function
+
+        Notes
+        -----
+        The objective function given as an array must have the size
+        to be one.
+        """
 
         if obj.size > 1:
             raise ValueError('Incorrect function dimension.')
@@ -255,6 +276,19 @@ class Model:
         self.dupdate = True
 
     def max(self, obj):
+        """
+        Maximize the given objective function.
+
+        Parameters
+        ----------
+        obj
+            An objective function
+
+        Notes
+        -----
+        The objective function given as an array must have the size
+        to be one.
+        """
 
         if obj.size > 1:
             raise ValueError('Incorrect function dimension.')
@@ -265,6 +299,22 @@ class Model:
         self.dupdate = True
 
     def minsup(self, obj, ambset):
+        """
+        Minimize the worst-case expected objective value over the given
+        ambiguity set.
+
+        Parameters
+        ----------
+        obj
+            Objective function involving random variables
+        ambset : Ambiguity
+            The ambiguity set defined for the worst-case expectation
+
+        Notes
+        -----
+        The ambiguity set defined for the objective function is considered
+        the default ambiguity set for the distritionally robust model.
+        """
 
         if np.prod(obj.shape) > 1:
             raise ValueError('Incorrect function dimension.')
@@ -277,6 +327,23 @@ class Model:
 
     def maxinf(self, obj, ambset):
 
+        """
+        Maximize the worst-case expected objective value over the given
+        ambiguity set.
+
+        Parameters
+        ----------
+        obj
+            Objective function involving random variables
+        ambset : Ambiguity
+            The ambiguity set defined for the worst-case expectation
+
+        Notes
+        -----
+        The ambiguity set defined for the objective function is considered
+        the default ambiguity set for the distritionally robust model.
+        """
+
         if np.prod(obj.shape) > 1:
             raise ValueError('Incorrect function dimension.')
 
@@ -415,10 +482,12 @@ class Model:
                     if is_equal == 1:
 
                         left = DecLinConstr(constr.model,
-                                            constr.linear, constr.const, 0,
+                                            constr.linear, constr.const,
+                                            np.zeros(constr.linear.shape[0]),
                                             constr.event_adapt, constr.ctype)
                         right = DecLinConstr(constr.model,
-                                             -constr.linear, -constr.const, 0,
+                                             -constr.linear, -constr.const,
+                                             np.zeros(constr.linear.shape[0]),
                                              constr.event_adapt, constr.ctype)
                         return self.ro_to_roc(left) + self.ro_to_roc(right)
 
