@@ -85,6 +85,19 @@ class Model:
         self.dupdate = True
 
     def min(self, obj):
+        """
+        Minimize the given objective function.
+
+        Parameters
+        ----------
+        obj
+            An objective function
+
+        Notes
+        -----
+        The objective function given as an array must have the size
+        to be one.
+        """
 
         if obj.size > 1:
             raise ValueError('Incorrect function dimension.')
@@ -95,6 +108,19 @@ class Model:
         self.dupdate = True
 
     def max(self, obj):
+        """
+        Maximize the given objective function.
+
+        Parameters
+        ----------
+        obj
+            An objective function
+
+        Notes
+        -----
+        The objective function given as an array must have the size
+        to be one.
+        """
 
         if obj.size > 1:
             raise ValueError('Incorrect function dimension.')
@@ -286,7 +312,7 @@ class Model:
                 is generated if the option is True.
             params : dict
                 A dictionary that specifies parameters of the selected solver.
-                So far the argument only applies to Gurobi and MOSEK.
+                So far the argument only applies to Gurobi, CPLEX,and MOSEK.
         """
 
         if solver is None:
@@ -432,10 +458,6 @@ class Vars:
                             shape=(dim, self.model.last))
         const = np.zeros(self.shape)
 
-        # if self.sparray is None:
-        #     self.sparray = sparse_array(self.shape)
-        #     self.sparray = self.sv_array()
-
         return Affine(self.model, linear, const, self.sparray)
 
     def get_ind(self):
@@ -630,18 +652,6 @@ class VarSub(Vars):
 
     def __le__(self, other):
 
-        """
-        if not isinstance(other, (Real, np.ndarray)):
-            return self.to_affine().__le__(other)
-
-        upper = super().__le__(other)
-        indices = self.indices.reshape((self.indices.size, ))
-        bound_indices = upper.indices.reshape((upper.indices.size, ))[indices]
-        bound_values = upper.values.reshape(upper.values.size)[indices]
-
-        return Bounds(upper.model, bound_indices, bound_values, 'U')
-        """
-
         upper = super().__le__(other)
         if isinstance(upper, Bounds):
             indices = self.indices.reshape((self.indices.size, ))
@@ -652,22 +662,8 @@ class VarSub(Vars):
         else:
             return self.to_affine().__le__(other)
 
-
     def __ge__(self, other):
 
-
-        """
-        if not isinstance(other, (Real, np.ndarray)):
-            return self.to_affine().__ge__(other)
-
-        lower = super().__ge__(other)
-        indices = self.indices.reshape((self.indices.size, ))
-        bound_indices = lower.indices.reshape((lower.indices.size, ))[indices]
-        bound_values = lower.values.reshape((lower.indices.size, ))[indices]
-
-        return Bounds(lower.model, bound_indices, bound_values, 'L')
-        """
-
         lower = super().__ge__(other)
         if isinstance(lower, Bounds):
             indices = self.indices.reshape((self.indices.size, ))
@@ -1090,9 +1086,12 @@ class Affine:
     def __eq__(self, other):
 
         left = self - other
-        return LinConstr(left.model, left.linear,
-                         -left.const.reshape((left.const.size,)),
-                         np.ones(left.const.size))
+        if isinstance(left, Affine) and not isinstance(left, DecAffine):
+            return LinConstr(left.model, left.linear,
+                             -left.const.reshape((left.const.size,)),
+                             np.ones(left.const.size))
+        else:
+            return left.__eq__(0)
         ##########
 
 
@@ -1277,15 +1276,6 @@ class RoAffine:
                 right_term = right.rand_to_roaffine(left.dec_model)
                 return left.__add__(right_term)
             elif other.model == self.dec_model:
-                # raffine = self.raffine + np.zeros((other.size,
-                #                                    self.raffine.shape[1]))
-                # affine = self.affine + other
-
-                # sparray = self.sv_array()
-                # zero = self.sv_zeros(other.size)
-                # sparse = sv_to_csr(sparray + zero)
-                # raffine = sparse @ self.raffine
-
                 if other.shape != self.shape:
                     left = self * np.ones(other.shape)
                     right = other + np.zeros(self.shape)
@@ -1314,13 +1304,6 @@ class RoAffine:
                                     shape=[size, self.size])
                 raffine = sparse @ self.raffine
 
-            """
-            sparray = self.sv_array()
-            zero = self.sv_zeros(other.size)
-            sparse = sv_to_csr(sparray + zero)
-            raffine = sparse @ self.raffine
-            """
-
             affine = self.affine + other
             return RoAffine(raffine, affine, self.rand_model)
         else:
@@ -1344,14 +1327,6 @@ class RoAffine:
         if isinstance(other, Real):
             other = np.array([other])
 
-        """
-        svarray = self.affine.sv_array()
-        new_svarray = svarray * other
-        if not isinstance(new_svarray, np.ndarray):
-            new_svarray = np.array([new_svarray])
-
-        new_raffine = sv_to_csr(new_svarray) @ self.raffine
-        """
         new_raffine = sparse_mul(other, self) @ self.raffine
 
         return RoAffine(new_raffine, new_affine, self.rand_model)
@@ -1362,15 +1337,6 @@ class RoAffine:
         if isinstance(other, Real):
             other = np.array([other])
 
-        """
-        svarray = self.affine.sv_array()
-        new_svarray = other * svarray
-        if not isinstance(new_svarray, np.ndarray):
-            new_svarray = np.array([new_svarray])
-
-        new_raffine = sv_to_csr(new_svarray) @ self.raffine
-        """
-
         new_raffine = sparse_mul(other, self) @ self.raffine
 
         return RoAffine(new_raffine, new_affine, self.rand_model)
@@ -1381,15 +1347,6 @@ class RoAffine:
 
         new_affine = self.affine @ other
 
-        """
-        svarray = self.affine.sv_array()
-        new_svarray = svarray @ other
-        if not isinstance(new_svarray, np.ndarray):
-            new_svarray = np.array([new_svarray])
-
-        new_raffine = sv_to_csr(new_svarray) @ self.raffine
-        """
-
         new_raffine = sp_lmatmul(other, self, new_affine.shape) @ self.raffine
 
         return RoAffine(new_raffine, new_affine, self.rand_model)
@@ -1400,15 +1357,6 @@ class RoAffine:
 
         new_affine = other @ self.affine
 
-        """
-        svarray = self.affine.sv_array()
-        new_svarray = other @ svarray
-        if not isinstance(new_svarray, np.ndarray):
-            new_svarray = np.array([new_svarray])
-
-        new_raffine = sv_to_csr(new_svarray) @ self.raffine
-        """
-
         new_raffine = sp_matmul(other, self, new_affine.shape) @ self.raffine
 
         return RoAffine(new_raffine, new_affine, self.rand_model)
@@ -1483,6 +1431,9 @@ class Bounds:
 
 
 class ConeConstr:
+    """
+    The ConeConstr class creates an object of second-order cone constraints
+    """
 
     def __init__(self, model, left_var, left_index, right_var, right_index):
 
@@ -1509,6 +1460,16 @@ class RoConstr:
         self.support = None
 
     def forall(self, *args):
+        """
+        Specify the uncertainty set of the constraints involving random
+        variables. The given arguments are constraints or collections of
+        constraints used for defining the uncertainty set.
+
+        Notes
+        -----
+        The uncertainty set defined by this method overrides the default
+        uncertainty set defined for the worst-case objective.
+        """
 
         constraints = []
         for items in args:
@@ -1584,6 +1545,10 @@ class RoConstr:
 
 
 class DecVar(Vars):
+    """
+    The DecVar class creates an object of generic variable array
+    (here-and-now or wait-and-see) for adaptive DRO models
+    """
 
     def __init__(self, dro_model, dvars, fixed=True, name=None):
 
@@ -1703,7 +1668,7 @@ class DecVar(Vars):
                     outputs.append(coeff.reshape(self.shape))
                 else:
                     rv_shape = rvar.to_affine().shape
-                    outputs.append(coeff.reshape(rv_shape + self.shape))
+                    outputs.append(coeff.reshape(self.shape + rv_shape))
 
             if len(outputs) > 1:
                 ind_label = self.dro_model.series_scen.index
@@ -1796,6 +1761,9 @@ class DecVarSub(VarSub):
 
 
 class RandVar(Vars):
+    """
+    The RandVar class creates an object of random variable array
+    """
 
     def __init__(self, svars, evars):
 
@@ -2376,6 +2344,10 @@ class DecRule:
 
         return self.to_affine().__add__(other)
 
+    def __radd__(self, other):
+
+        return self.__add__(other)
+
     def __sub__(self, other):
 
         return self.to_affine().__sub__(other)
@@ -2441,7 +2413,7 @@ class DecRule:
                 return ldr_coeff[:, rand_ind].reshape(self.shape)
             else:
                 rv_shape = rvar.to_affine().shape
-                return ldr_coeff[:, rand_ind].reshape(rv_shape + self.shape)
+                return ldr_coeff[:, rand_ind].reshape(self.shape + rv_shape)
 
 
 class DecRuleSub:
