@@ -115,6 +115,19 @@ class Model:
         return new_ldr
 
     def min(self, obj):
+        """
+        Minimize the given objective function.
+
+        Parameters
+        ----------
+        obj
+            An objective function
+
+        Notes
+        -----
+        The objective function given as an array must have the size
+        to be one.
+        """
 
         if obj.size > 1:
             raise ValueError('Incorrect function dimension.')
@@ -125,6 +138,19 @@ class Model:
         self.dupdate = True
 
     def max(self, obj):
+        """
+        Maximize the given objective function.
+
+        Parameters
+        ----------
+        obj
+            An objective function
+
+        Notes
+        -----
+        The objective function given as an array must have the size
+        to be one.
+        """
 
         if obj.size > 1:
             raise ValueError('Incorrect function dimension.')
@@ -136,6 +162,23 @@ class Model:
 
     def minmax(self, obj, *args):
 
+        """
+        Minimize the maximum objective value over the given uncertainty set.
+
+        Parameters
+        ----------
+        obj
+            Objective function involving random variables
+        *args
+            Constraints or collections of constraints of random variables
+            used for defining the uncertainty set
+
+        Notes
+        -----
+        The uncertainty set defined for the objective function is considered
+        the default uncertainty set for the robust model.
+        """
+
         if np.prod(obj.shape) > 1:
             raise ValueError('Incorrect function dimension.')
 
@@ -161,6 +204,23 @@ class Model:
 
     def maxmin(self, obj, *args):
 
+        """
+        Maximize the minimum objective value over the given uncertainty set.
+
+        Parameters
+        ----------
+        obj
+            Objective function involving random variables
+        *args
+            Constraints or collections of constraints of random variables
+            used for defining the uncertainty set
+
+        Notes
+        -----
+        The uncertainty set defined for the objective function is considered
+        the default uncertainty set for the robust model.
+        """
+
         if np.prod(obj.shape) > 1:
             raise ValueError('Incorrect function dimension.')
 
